@@ -83,8 +83,8 @@ class CouchDBLogHandler(logging.StreamHandler):
             sys.stdout or sys.stderr may be used.
     """
 
-    def __init__(self, host='localhost', port=5984, database='logs', create_database=False,
-        username=None, password=None):
+    def __init__(self, host='localhost', port=5984, database='logs',
+        create_database=False, username=None, password=None):
         """
             Initialize the couchdb handler
 
@@ -93,7 +93,7 @@ class CouchDBLogHandler(logging.StreamHandler):
         :param database: database's name for logging
         :param username: user's name for logging in the database
         :param password: password for logging in the database
-        :param create_database: boolean to create the database if it does not exist
+        :param create_database: bool to create the database if it does not exist
         """
         super(CouchDBLogHandler, self).__init__()
 
@@ -123,6 +123,16 @@ class CouchDBLogHandler(logging.StreamHandler):
             except CouchDBSession.CouchDBException:
                 self.session.put(self.db_url)
 
+    def new_format(self, format_function):
+        """
+            Change the format logging
+
+        :param format_function: function to generate couchdb logs from record
+
+        REQUIRED: The function must return a json.dumps to post in couchdb
+        """
+        self.format = format_function
+
     def format(self, record):
         """
             Format a logging record to couchdb record
